==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Benvingut @nom@!',
	'c_accueil_configurer_site' => 'Configura la teva pàgina',
	'c_accueil_configurer_site_texte' => 'Una de les primeres coses a fer és donar un nom a la teva pàgina. Ara s’anomena "@nom@". El nom de la pàgina apareix a la part superior d’aquesta pàgina. En fer-hi clic pots canviar-li el nom, així com afegir-li un logotip i un eslògan.',
	'c_accueil_publication' => 'Publica-ho!',
	'c_accueil_publication_texte' => 'Per a publicar una pàgina has d’escriure un article.
També cal que creïs almenys una secció per a poder fer-ho. Pots continuar fent clic al menú "Edició" i després a "Seccions".',
	'c_accueil_texte' => 'Acabes d’entrar a la zona privada d’SPIP.',
	'c_accueil_texte_revenir' => 'Aquesta pàgina mostra la última activitat editorial de la teva pàgina.
Pots visitar aquesta pàgina en qualsevol moment fent clic al botó de la casa,
a la part superior, a sota del teu nom.',
	'c_article_redaction' => 'L’article s’està escrivint.',
	'c_article_redaction_redacteur' => 'L’edició d’aquest article està en curs.',
	'c_article_redaction_redacteur_texte' => 'Per a proposar el teu article als administradors de la pàgina i als altres editors, canvia, dins el bloc de la columna del costat, "edició en curs" per "enviat per avaluar".',
	'c_article_redaction_texte' => 'Per a publicar aquest article a la pàgina pública, canvia’n l’estat.
Al bloc de la columna del costat, canvia "edició en curs" per "publicat en línia".
',
	'c_articles_creer' => 'Com escriure un article?',
	'c_articles_creer_texte' => 'No pots escriure un article des d’aquesta pàgina
		llevat que hi hagi almenys una secció a la teva pàgina.
		Pots crear-la des del menú "Seccions" a sota d’"Editar".
		',
	'c_job' => 'Feina per a fer...',
	'c_job_texte' => 'Aquesta pàgina enumera les properes tasques de manteniment que SPIP haurà de fer. Aquestes tasques s’executen amb regularitat o de manera ocasional degut al pesat processament que requereixen els plugins com l’enviament de correu electrònic massiu.',
	'c_rubrique_publier' => 'Escriu un article',
	'c_rubrique_publier_texte' => 'Una secció és visible a la pàgina pública només des del moment que conté almenys un contingut publicat, com, per exemple, un article publicat.
Així doncs, escriu un article. Pots fer-ho des de la pàgina a sota de la descripció de la teva secció.',
	'c_rubriques_creer' => 'Crea la primera secció!',
	'c_rubriques_creer_texte' => 'Les seccions són l’estructura bàsica de la pàgina, i pots escriure-hi articles. Comença per crear la primera secció.',

	// E
	'explication_activer_compagnon' => 'El company afegeix comentaris a algunes pàgines de la zona privada per ajudar a encarregar-se d’SPIP. Voldrieu activar-lo?',
	'explication_reinitialiser_compagnon' => 'Llavors els missatges ja vistos per un autor no es mostraran.
Voldrieu reiniciar aquests missatges?',

	// L
	'label_activer_compagnon' => 'Activar el Company?',
	'label_reinitialiser_compagnon' => 'Reiniciar els missatges del Company?',

	// O
	'ok' => 'D’acord',
	'ok_bien' => 'Molt bé!',
	'ok_jai_compris' => 'Ja ho tinc!',
	'ok_merci' => 'Gràcies',
	'ok_parfait' => 'Perfecte!',

	// R
	'reinitialisation' => 'Reinici',
	'reinitialisation_ok' => 'Reinici complet',
	'reinitialiser' => 'Reiniciar',
	'reinitialiser_moi' => 'Sí, només aquells que ja he llegit',
	'reinitialiser_tous' => 'Sí, sigui qui sigui l’autor',

	// T
	'titre_compagnon' => 'El Company',
	'titre_page_configurer_compagnon' => 'Configura el company'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_ca.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Benvingut @nom@!',
	'c_accueil_configurer_site' => 'Configura la teva pàgina',
	'c_accueil_configurer_site_texte' => 'Una de les primeres coses a fer és donar un nom a la teva pàgina. Ara s’anomena "@nom@". El nom de la pàgina apareix a la part superior d’aquesta pàgina. En fer-hi clic pots canviar-li el nom, així com afegir-li un logotip i un eslògan.',
	'c_accueil_publication' => 'Publica-ho!',
	'c_accueil_publication_texte' => 'Per a publicar una pàgina has d’escriure un article.
També cal que creïs almenys una secció per a poder fer-ho. Pots continuar fent clic al menú "Edició" i després a "Seccions".',
	'c_accueil_texte' => 'Acabes d’entrar a la zona privada d’SPIP.',
	'c_accueil_texte_revenir' => 'Aquesta pàgina mostra la última activitat editorial de la teva pàgina.
Pots visitar aquesta pàgina en qualsevol moment fent clic al botó de la casa,
a la part superior, a sota del teu nom.', # MODIF
	'c_article_redaction' => 'L’article s’està escrivint.',
	'c_article_redaction_redacteur' => 'L’edició d’aquest article està en curs.',
	'c_article_redaction_redacteur_texte' => 'Per a proposar el teu article als administradors de la pàgina i als altres editors, canvia, dins el bloc de la columna del costat, "edició en curs" per "enviat per avaluar".',
	'c_article_redaction_texte' => 'Per a publicar aquest article a la pàgina pública, canvia’n l’estat.
Al bloc de la columna del costat, canvia "edició en curs" per "publicat en línia".
',
	'c_articles_creer' => 'Com escriure un article?',
	'c_articles_creer_texte' => 'No pots escriure un article des d’aquesta pàgina
		llevat que hi hagi almenys una secció a la teva pàgina.
		Pots crear-la des del menú "Seccions" a sota d’"Editar".
		',
	'c_job' => 'Feina per a fer...',
	'c_job_texte' => 'Aquesta pàgina enumera les properes tasques de manteniment que SPIP haurà de fer. Aquestes tasques s’executen amb regularitat o de manera ocasional degut al pesat processament que requereixen els plugins com l’enviament de correu electrònic massiu.',
	'c_rubrique_publier' => 'Escriu un article',
	'c_rubrique_publier_texte' => 'Una secció és visible a la pàgina pública només des del moment que conté almenys un contingut publicat, com, per exemple, un article publicat.
Així doncs, escriu un article. Pots fer-ho des de la pàgina a sota de la descripció de la teva secció.',
	'c_rubriques_creer' => 'Crea la primera secció!',
	'c_rubriques_creer_texte' => 'Les seccions són l’estructura bàsica de la pàgina, i pots escriure-hi articles. Comença per crear la primera secció.',

	// E
	'explication_activer_compagnon' => 'El company afegeix comentaris a algunes pàgines de la zona privada per ajudar a encarregar-se d’SPIP. Voldrieu activar-lo?',
	'explication_reinitialiser_compagnon' => 'Llavors els missatges ja vistos per un autor no es mostraran.
Voldrieu reiniciar aquests missatges?',

	// L
	'label_activer_compagnon' => 'Activar el Company?',
	'label_reinitialiser_compagnon' => 'Reiniciar els missatges del Company?',

	// O
	'ok' => 'D’acord',
	'ok_bien' => 'Molt bé!',
	'ok_jai_compris' => 'Ja ho tinc!',
	'ok_merci' => 'Gràcies',
	'ok_parfait' => 'Perfecte!',

	// R
	'reinitialisation' => 'Reinici',
	'reinitialisation_ok' => 'Reinici complet',
	'reinitialiser' => 'Reiniciar',
	'reinitialiser_moi' => 'Sí, només aquells que ja he llegit',
	'reinitialiser_tous' => 'Sí, sigui qui sigui l’autor',

	// T
	'titre_compagnon' => 'El Company',
	'titre_page_configurer_compagnon' => 'Configura el company'
);

?>
